==> liveqa-1.0.0.tgz: package/distribution/index.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Config = require('./config.js');
var Event = require('./event.js');

var LiveQA = function (_Config) {
  (0, _inherits3.default)(LiveQA, _Config);

  function LiveQA() {
    (0, _classCallCheck3.default)(this, LiveQA);
    return (0, _possibleConstructorReturn3.default)(this, (LiveQA.__proto__ || (0, _getPrototypeOf2.default)(LiveQA)).apply(this, arguments));
  }

  (0, _createClass3.default)(LiveQA, null, [{
    key: 'track',
    value: function track(eventName) {
      var userParams = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var properties = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      var params = (0, _assign2.default)(userParams, { type: 'track' });

      Event.create(this, eventName, params, properties);
    }
  }]);
  return LiveQA;
}(Config);

module.exports = LiveQA;

==> liveqa-1.1.1.tgz: package/distribution/index.js <==
'use strict';

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Config = require('./config.js');
var Event = require('./event.js');

var LiveQA = function (_Config) {
  (0, _inherits3.default)(LiveQA, _Config);

  function LiveQA() {
    (0, _classCallCheck3.default)(this, LiveQA);
    return (0, _possibleConstructorReturn3.default)(this, (LiveQA.__proto__ || (0, _getPrototypeOf2.default)(LiveQA)).apply(this, arguments));
  }

  (0, _createClass3.default)(LiveQA, null, [{
    key: 'track',
    value: function track(eventName) {
      var userParams = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var properties = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      if (!this.enabled) return true;

      var params = (0, _assign2.default)(userParams, { type: 'track' });

      return Event.create(this, eventName, params, properties);
    }
  }]);
  return LiveQA;
}(Config);

module.exports = LiveQA;
